@@ -13,22 +13,24 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import os
 from savanna.openstack.common import jsonutils as json
 from savanna.openstack.common import log as logging
-from savanna.plugins.hdp import configprovider as cfg
 from savanna.plugins.hdp import savannautils as utils
+from savanna.plugins.hdp.versions import versionhandlerfactory as vhf
+import savanna.utils.openstack.nova as n_helper
+
 
 LOG = logging.getLogger(__name__)
 
 
 class ClusterSpec():
-    def __init__(self, cluster_template, cluster=None):
+    def __init__(self, cluster_template, cluster=None, version='1.3.2'):
         self.services = []
         self.configurations = {}
         self.node_groups = {}
         self.servers = None
         self.str = cluster_template
+        self.version = version
 
         if cluster:
             self.servers = self._get_servers_from_savanna_cluster(cluster)
@@ -59,10 +61,7 @@ class ClusterSpec():
     def _get_servers_from_savanna_cluster(self, cluster):
         servers = []
         for node_group in cluster.node_groups:
-            for server in node_group.instances:
-                setattr(server, 'role', node_group.name)
-                setattr(server, 'node_processes', node_group.node_processes)
-                servers.append(server)
+            servers += node_group.instances
 
         return servers
 
@@ -151,11 +150,12 @@ class ClusterSpec():
         host_id = 1
 
         for server in self.servers:
+            instance_info = n_helper.get_instance_info(server)
             hosts.append({'host_id': host_id,
                           'hostname': server.hostname,
-                          'role': server.role,
-                          'vm_image': server.nova_info.image,
-                          'vm_flavor': server.nova_info.flavor,
+                          'role': utils.get_host_role(server),
+                          'vm_image': instance_info.image,
+                          'vm_flavor': instance_info.flavor,
                           'public_ip': server.management_ip,
                           'private_ip': server.internal_ip})
             host_id += 1
@@ -216,12 +216,11 @@ class User():
 class NormalizedClusterConfig():
     def __init__(self, cluster_spec):
         #TODO(jspeidel): get from stack config
-        self.hadoop_version = '1.3.0'
+        self.hadoop_version = cluster_spec.version
         self.cluster_configs = []
         self.node_groups = []
-        self.config = cfg.ConfigurationProvider(
-            json.load(open(os.path.join(os.path.dirname(__file__), 'resources',
-                                        'ambari-config-resource.json'), "r")))
+        self.handler = vhf.VersionHandlerFactory.get_instance().\
+            get_version_handler(self.hadoop_version)
 
         self._parse_configurations(cluster_spec.configurations)
         self._parse_node_groups(cluster_spec.node_groups)
@@ -243,7 +242,7 @@ class NormalizedClusterConfig():
     def _get_property_target(self, config, prop):
         # Once config resource is complete we won't need to fall through
         # based on config type
-        target = self.config.get_applicable_target(prop)
+        target = self.handler.get_applicable_target(prop)
         if not target:
             if config == 'hdfs-site':
                 target = 'HDFS'
