@@ -13,8 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import novaclient.exceptions as nova_ex
+from oslo.config import cfg
 
+import novaclient.exceptions as nova_ex
+from savanna import conductor as cond
+from savanna import context
 import savanna.exceptions as ex
 import savanna.plugins.base as plugin_base
 import savanna.service.api as api
@@ -22,6 +25,10 @@ import savanna.utils.openstack.keystone as keystone
 import savanna.utils.openstack.nova as nova
 
 
+CONF = cfg.CONF
+conductor = cond.API
+
+
 def _get_plugin_configs(plugin_name, hadoop_version, scope=None):
     pl_confs = {}
     for config in plugin_base.PLUGINS.get_plugin(
@@ -91,7 +98,12 @@ def check_node_group_basic_fields(plugin_name, hadoop_version, ng,
                                   plugin_configs=None):
 
     if ng.get('node_group_template_id'):
-        check_node_group_template_exists(ng['node_group_template_id'])
+        ng_tmpl_id = ng['node_group_template_id']
+        check_node_group_template_exists(ng_tmpl_id)
+        ng_tmpl = api.get_node_group_template(ng_tmpl_id).to_wrapped_dict()
+        check_node_group_basic_fields(plugin_name, hadoop_version,
+                                      ng_tmpl['node_group_template'],
+                                      plugin_configs)
 
     if ng.get('node_configs'):
         check_node_group_configs(plugin_name, hadoop_version,
@@ -146,6 +158,12 @@ def check_cluster_unique_name(name):
                                             " exists" % name)
 
 
+def check_cluster_exists(id):
+    if not api.get_cluster(id):
+        raise ex.InvalidException("Cluster with id '%s'"
+                                  " doesn't exist" % id)
+
+
 def check_keypair_exists(keypair):
     try:
         nova.client().keypairs.get(keypair)
@@ -162,13 +180,22 @@ def check_cluster_template_unique_name(name):
 
 
 def check_cluster_template_exists(cluster_template_id):
-    if not api.get_cluster_templates(id=cluster_template_id):
+    if not api.get_cluster_template(id=cluster_template_id):
         raise ex.InvalidException("Cluster template with id '%s'"
                                   " doesn't exist" % cluster_template_id)
 
 
+def check_node_groups_in_cluster_templates(plugin_name, hadoop_version,
+                                           cluster_template_id):
+    c_t = api.get_cluster_template(id=cluster_template_id)
+    n_groups = c_t.to_wrapped_dict()['cluster_template']['node_groups']
+    check_network_config(n_groups)
+    for node_group in n_groups:
+        check_node_group_basic_fields(plugin_name, hadoop_version, node_group)
+
 ## NodeGroup templates related checks
 
+
 def check_node_group_template_unique_name(name):
     if name in [t.name for t in api.get_node_group_templates()]:
         raise ex.NameAlreadyExistsException("NodeGroup template with name '%s'"
@@ -176,11 +203,33 @@ def check_node_group_template_unique_name(name):
 
 
 def check_node_group_template_exists(ng_tmpl_id):
-    if not api.get_node_group_templates(id=ng_tmpl_id):
+    if not api.get_node_group_template(id=ng_tmpl_id):
         raise ex.InvalidException("NodeGroup template with id '%s'"
                                   " doesn't exist" % ng_tmpl_id)
 
 
+def check_network_config(node_groups):
+    if CONF.use_floating_ips and CONF.use_neutron:
+        for ng in node_groups:
+            if not _get_floating_ip_pool(ng):
+                raise ex.MissingFloatingNetworkException(ng.get('name'))
+
+
+def _get_floating_ip_pool(node_group):
+    if node_group.get('floating_ip_pool'):
+        return node_group['floating_ip_pool']
+
+    if node_group.get('node_group_template_id'):
+        ctx = context.ctx()
+        ngt = conductor.node_group_template_get(
+            ctx,
+            node_group['node_group_template_id'])
+        if ngt.get('floating_ip_pool'):
+            return ngt['floating_ip_pool']
+
+    return None
+
+
 ## Cluster scaling
 
 def check_resize(cluster, r_node_groups):
