@@ -15,47 +15,54 @@
 
 import unittest2
 
-from savanna.db import models as m
 from savanna.plugins.general import exceptions as ex
 from savanna.plugins.vanilla import config_helper as c_h
+from savanna.plugins.vanilla import mysql_helper as m_h
 from savanna.plugins.vanilla import plugin as p
+from savanna.tests.unit.plugins.vanilla import test_utils as tu
 
 
 class VanillaPluginTest(unittest2.TestCase):
     def setUp(self):
         self.pl = p.VanillaProvider()
-        self.cl = m.Cluster("cluster1", "tenant1", "vanilla", "1.1.2")
-        self.ng1 = m.NodeGroup("nn", "f1", ["namenode"], 1)
-        self.ng2 = m.NodeGroup("jt", "f1", ["jobtracker"], 1)
-        self.ng3 = m.NodeGroup("tt", "f1", ["tasktracker"], 10)
-        self.cl_configs = self.pl.get_configs("1.1.2")
 
     def test_validate(self):
-        self.cl.node_groups = [self.ng1]
-        self.pl.validate(self.cl)
-        with self.assertRaises(ex.NotSingleNameNodeException):
-            self.ng1.count = 0
-            self.pl.validate(self.cl)
-        with self.assertRaises(ex.NotSingleNameNodeException):
-            self.ng1.count = 2
-            self.pl.validate(self.cl)
-        self.ng1.count = 1
+        self.ng = []
+        self.ng.append(tu._make_ng_dict("nn", "f1", ["namenode"], 0))
+        self.ng.append(tu._make_ng_dict("jt", "f1", ["jobtracker"], 0))
+        self.ng.append(tu._make_ng_dict("tt", "f1", ["tasktracker"], 0))
+        self.ng.append(tu._make_ng_dict("oozie", "f1", ["oozie"], 0))
 
-        self.cl.node_groups.append(self.ng2)
-        self.pl.validate(self.cl)
-        with self.assertRaises(ex.NotSingleJobTrackerException):
-            self.ng2.count = 2
-            self.pl.validate(self.cl)
+        self._validate_case(1, 1, 10, 1)
+
+        with self.assertRaises(ex.NotSingleNameNodeException):
+            self._validate_case(0, 1, 10, 1)
+        with self.assertRaises(ex.NotSingleNameNodeException):
+            self._validate_case(2, 1, 10, 1)
 
-        self.cl.node_groups.append(self.ng3)
-        self.ng2.count = 1
-        self.pl.validate(self.cl)
         with self.assertRaises(ex.TaskTrackersWithoutJobTracker):
-            self.ng2.count = 0
-            self.pl.validate(self.cl)
+            self._validate_case(1, 0, 10, 1)
+        with self.assertRaises(ex.NotSingleJobTrackerException):
+            self._validate_case(1, 2, 10, 1)
+
+        with self.assertRaises(ex.NotSingleOozieException):
+            self._validate_case(1, 1, 0, 2)
+        with self.assertRaises(ex.OozieWithoutJobTracker):
+            self._validate_case(1, 0, 0, 1)
+
+    def _validate_case(self, *args):
+        lst = []
+        for i in range(0, len(args)):
+            self.ng[i]['count'] = args[i]
+            lst.append(self.ng[i])
+
+        cl = tu._create_cluster("cluster1", "tenant1", "vanilla", "1.2.1", lst)
+
+        self.pl.validate(cl)
 
     def test_get_configs(self):
-        for cfg in self.cl_configs:
+        cl_configs = self.pl.get_configs("1.2.1")
+        for cfg in cl_configs:
             if cfg.config_type is "bool":
                 self.assertIsInstance(cfg.default_value, bool)
             elif cfg.config_type is "int":
@@ -66,6 +73,9 @@ class VanillaPluginTest(unittest2.TestCase):
 
     def test_extract_environment_configs(self):
         env_configs = {
+            "JobFlow": {
+                'Oozie Heap Size': 4000
+            },
             "MapReduce": {
                 'Job Tracker Heap Size': 1000,
                 'Task Tracker Heap Size': "2000"
@@ -80,6 +90,7 @@ class VanillaPluginTest(unittest2.TestCase):
         self.assertListEqual(c_h.extract_environment_confs(env_configs),
                              ['HADOOP_NAMENODE_OPTS=\\"-Xmx3000m\\"',
                               'HADOOP_DATANODE_OPTS=\\"-Xmx4000m\\"',
+                              'CATALINA_OPTS=\\"-Xmx4000m\\"',
                               'HADOOP_JOBTRACKER_OPTS=\\"-Xmx1000m\\"',
                               'HADOOP_TASKTRACKER_OPTS=\\"-Xmx2000m\\"'])
 
@@ -104,3 +115,51 @@ class VanillaPluginTest(unittest2.TestCase):
                               ('dfs.replication', 3),
                               ('mapred.reduce.tasks', 2),
                               ('io.sort.factor', 10)])
+
+    def test_general_configs(self):
+        gen_config = {
+            c_h.ENABLE_SWIFT.name: {
+                'default_value': c_h.ENABLE_SWIFT.default_value,
+                'conf': {
+                    'fs.swift.enabled': True
+                }
+            },
+            c_h.ENABLE_MYSQL.name: {
+                'default_value': c_h.ENABLE_MYSQL.default_value,
+                'conf': {
+                    'oozie.service.JPAService.jdbc.username': 'oozie'
+                }
+            }
+        }
+        all_configured = {
+            'fs.swift.enabled': True,
+            'oozie.service.JPAService.jdbc.username': 'oozie'
+        }
+        configs = {
+            'general': {
+                'Enable Swift': True
+            }
+        }
+        cfg = c_h.generate_cfg_from_general({}, configs, gen_config)
+        self.assertDictEqual(cfg, all_configured)
+        configs['general'].update({'Enable MySQL': False})
+        cfg = c_h.generate_cfg_from_general({}, configs, gen_config)
+        self.assertDictEqual(cfg, {'fs.swift.enabled': True})
+        configs['general'].update({
+            'Enable Swift': False,
+            'Enable MySQL': False
+        })
+        cfg = c_h.generate_cfg_from_general({}, configs, gen_config)
+        self.assertDictEqual(cfg, {})
+        configs = {}
+        cfg = c_h.generate_cfg_from_general({}, configs, gen_config)
+        self.assertDictEqual(cfg, all_configured)
+
+    def test_get_mysql_configs(self):
+        cfg = m_h.get_required_mysql_configs(None, None)
+        self.assertDictEqual(cfg, m_h.get_oozie_mysql_configs())
+        cfg = m_h.get_required_mysql_configs("metastore_host", "passwd")
+        cfg_to_compare = m_h.get_oozie_mysql_configs()
+        cfg_to_compare.update(m_h.get_hive_mysql_configs(
+            "metastore_host", "passwd"))
+        self.assertDictEqual(cfg, cfg_to_compare)
