@@ -19,6 +19,7 @@ import flask
 from werkzeug import datastructures
 
 from savanna import context
+from savanna import exceptions as ex
 from savanna.openstack.common import log as logging
 from savanna.openstack.common import wsgi
 
@@ -38,6 +39,9 @@ class Rest(flask.Blueprint):
     def put(self, rule, status_code=202):
         return self._mroute('PUT', rule, status_code)
 
+    def put_file(self, rule, status_code=202):
+        return self._mroute('PUT', rule, status_code, file_upload=True)
+
     def delete(self, rule, status_code=204):
         return self._mroute('DELETE', rule, status_code)
 
@@ -65,12 +69,14 @@ class Rest(flask.Blueprint):
                     flask.request.status_code = status
 
                 kwargs.pop("tenant_id")
-
                 ctx = context.Context(
                     flask.request.headers['X-User-Id'],
                     flask.request.headers['X-Tenant-Id'],
                     flask.request.headers['X-Auth-Token'],
-                    flask.request.headers)
+                    flask.request.headers['X-Service-Catalog'],
+                    flask.request.headers['X-User-Name'],
+                    flask.request.headers['X-Tenant-Name'],
+                    flask.request.headers['X-Roles'].split(','))
                 context.set_ctx(ctx)
 
                 if flask.request.method in ['POST', 'PUT']:
@@ -78,7 +84,9 @@ class Rest(flask.Blueprint):
 
                 try:
                     return func(**kwargs)
-                except Exception, e:
+                except ex.SavannaException as e:
+                    return bad_request(e)
+                except Exception as e:
                     return internal_error(500, 'Internal Server Error', e)
 
             f_rule = "/<tenant_id>" + rule
@@ -115,30 +123,6 @@ def _init_resp_type(file_upload):
     flask.request.file_upload = file_upload
 
 
-def _clean_nones(obj):
-    if not isinstance(obj, dict) and not isinstance(obj, list):
-        return obj
-
-    if isinstance(obj, dict):
-        remove = []
-        for key, value in obj.iteritems():
-            if value is None:
-                remove.append(key)
-        for key in remove:
-            obj.pop(key)
-        for value in obj.values():
-            _clean_nones(value)
-    elif isinstance(obj, list):
-        new_list = []
-        for elem in obj:
-            elem = _clean_nones(elem)
-            if elem is not None:
-                new_list.append(elem)
-        return new_list
-
-    return obj
-
-
 def render(res=None, resp_type=None, status=None, **kwargs):
     if not res:
         res = {}
@@ -148,8 +132,6 @@ def render(res=None, resp_type=None, status=None, **kwargs):
         # can't merge kwargs into the non-dict res
         abort_and_log(500, "Non-dict and non-empty kwargs passed to render")
 
-    res = _clean_nones(res)
-
     status_code = getattr(flask.request, 'status_code', None)
     if status:
         status_code = status
