@@ -19,6 +19,7 @@ import jsonschema
 import six
 
 from savanna.openstack.common import uuidutils
+from savanna.swift import utils as su
 
 
 @jsonschema.FormatChecker.cls_checks('valid_name')
@@ -29,6 +30,17 @@ def validate_name_format(entry):
     return res is not None
 
 
+@jsonschema.FormatChecker.cls_checks('valid_job_location')
+def validate_job_location_format(entry):
+    if entry.startswith('savanna-db://'):
+        return uuidutils.is_uuid_like(entry[len("savanna-db://"):])
+    if entry.startswith(su.SWIFT_INTERNAL_PREFIX):
+        #TODO(tmckay):allow su.SWIFT_EXTERNAL_PREFIX in a future version
+        #TODO(nprivalova):add hostname validation
+        return True
+    return False
+
+
 @jsonschema.FormatChecker.cls_checks('valid_tag')
 def validate_valid_tag_format(entry):
     res = re.match(r"^(([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9\-_]"
@@ -44,7 +56,7 @@ def validate_uuid_format(entry):
 
 @jsonschema.FormatChecker.cls_checks('posix_path')
 def validate_posix_path(entry):
-    res = re.match("^(/([A-Z]|[a-z]|[0-9]|\-|_)+)*$", entry)
+    res = re.match("^(/([A-Z]|[a-z]|[0-9]|\-|_)+)+$", entry)
     return res is not None
 
 
@@ -78,10 +90,31 @@ class ConfigTypeMeta(type):
         return True
 
 
+class SimpleConfigTypeMeta(type):
+    def __instancecheck__(cls, instance):
+        # configs should be dict
+        if not isinstance(instance, dict):
+            return False
+
+        # check dict content
+        for conf_name, conf_value in six.iteritems(instance):
+            # keys should be strings, values should be int, string or bool
+            if not isinstance(conf_name, six.string_types):
+                return False
+            if not isinstance(conf_value,
+                              (six.string_types, six.integer_types)):
+                return False
+        return True
+
+
 class ConfigsType(dict):
     __metaclass__ = ConfigTypeMeta
 
 
+class SimpleConfigsType(dict):
+    __metaclass__ = SimpleConfigTypeMeta
+
+
 class FlavorTypeMeta(type):
     def __instancecheck__(cls, instance):
         try:
@@ -104,4 +137,5 @@ class ApiValidator(jsonschema.Draft4Validator):
             schema, format_checker=format_checker, types={
                 "configs": ConfigsType,
                 "flavor": FlavorType,
+                "simple_config": SimpleConfigsType,
             })
